==> ultra-erp-clean-v2.1.zip: src/Views/sales/shipments/index.php <==
<h5>Sotuv — Jo‘natmalar</h5>
<button class="btn btn-primary btn-sm mb-2" data-bs-toggle="modal" data-bs-target="#sNew"><i class="bi bi-truck"></i> Yangi jo‘natma</button>
<table class="table table-sm table-hover"><thead><tr><th>Kod</th><th>Sana</th><th>Ombor</th><th class="text-end">Jami</th><th class="text-end">COGS</th><th></th></tr></thead><tbody>
<?php foreach($rows as $r): ?><tr><td><?=$r['code']?></td><td><?=$r['date']?></td><td><?=$r['warehouse_id']?></td><td class="text-end"><?=$r['total']?></td><td class="text-end"><?=$r['cogs_total']?></td>
<td class="text-end"><form method="post" action="?r=sales/shipments/delete" onsubmit="return confirm('O‘chirish?')"><input type="hidden" name="id" value="<?=$r['id']?>"><button class="btn btn-outline-danger btn-sm"><i class="bi bi-trash"></i></button></form></td></tr><?php endforeach; ?></tbody></table>

<div class="modal fade" id="sNew" tabindex="-1"><div class="modal-dialog modal-xl"><div class="modal-content">
<div class="modal-header py-2"><h6 class="modal-title">Yangi jo‘natma</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="?r=sales/shipments/create"><div class="modal-body">
  <div class="row row-cols-1 row-cols-md-4 g-2">
    <div class="col"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" required></div>
    <div class="col"><label class="form-label">Sana</label><input type="date" class="form-control form-control-sm" name="date" required></div>
    <div class="col"><label class="form-label">Mijoz ID</label><input class="form-control form-control-sm" name="customer_id"></div>
    <div class="col"><label class="form-label">Ombor</label><input class="form-control form-control-sm" name="warehouse_id" value="1"></div>
  </div><hr class="my-2">
  <table class="table table-sm" id="sItems"><thead><tr><th>Mahsulot</th><th class="text-end">Miqdor</th><th class="text-end">Narx</th><th>COGS usuli</th><th class="text-end">Jami</th><th></th></tr></thead><tbody>
  <tr class="template" style="display:none"><td><select name="product_id[]" class="form-select form-select-sm"><option value="">—</option><?php foreach($prod as $p): ?><option value="<?=$p['id']?>"><?=$p['code']?> — <?=$p['name']?></option><?php endforeach; ?></select></td>
  <td><input name="qty[]" type="number" class="form-control form-control-sm text-end" step="0.001" value="1"></td>
  <td><input name="price[]" type="number" class="form-control form-control-sm text-end" step="0.01" value="0"></td>
  <td><select name="method[]" class="form-select form-select-sm"><option value="FIFO">FIFO</option><option value="FEFO">FEFO</option></select></td>
  <td class="text-end line-total">0.00</td><td><button type="button" class="btn btn-outline-secondary btn-sm" onclick="this.closest('tr').remove()"><i class="bi bi-trash"></i></button></td></tr>
  </tbody></table>
  <button type="button" class="btn btn-outline-primary btn-sm" onclick="ItemsTable.addRow('#sItems')"><i class="bi bi-plus"></i> Qator qo‘shish</button>
</div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>

==> ultra-erp-clean-v2.2.zip: src/Views/sales/shipments/index.php <==
<h5>Sotuv — Jo‘natmalar</h5>
<button class="btn btn-primary btn-sm mb-2" data-bs-toggle="modal" data-bs-target="#sNew"><i class="bi bi-truck"></i> Yangi jo‘natma</button>
<table class="table table-sm table-hover"><thead><tr><th>Kod</th><th>Sana</th><th>Ombor</th><th class="text-end">Jami</th><th class="text-end">COGS</th><th></th></tr></thead><tbody>
<?php foreach($rows as $r): ?><tr><td><?=$r['code']?></td><td><?=$r['date']?></td><td><?=$r['warehouse_id']?></td><td class="text-end"><?=$r['total']?></td><td class="text-end"><?=$r['cogs_total']?></td>
<td class="text-end"><form method="post" action="<?= \App\Core\Response::url(\'\1\') ?>" onsubmit="return confirm('O‘chirish?')"><input type="hidden" name="id" value="<?=$r['id']?>"><button class="btn btn-outline-danger btn-sm"><i class="bi bi-trash"></i></button></form></td></tr><?php endforeach; ?></tbody></table>

<div class="modal fade" id="sNew" tabindex="-1"><div class="modal-dialog modal-xl"><div class="modal-content">
<div class="modal-header py-2"><h6 class="modal-title">Yangi jo‘natma</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="<?= \App\Core\Response::url(\'\1\') ?>"><div class="modal-body">
  <div class="row row-cols-1 row-cols-md-4 g-2">
    <div class="col"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" required></div>
    <div class="col"><label class="form-label">Sana</label><input type="date" class="form-control form-control-sm" name="date" required></div>
    <div class="col"><label class="form-label">Mijoz ID</label><input class="form-control form-control-sm" name="customer_id"></div>
    <div class="col"><label class="form-label">Ombor</label><input class="form-control form-control-sm" name="warehouse_id" value="1"></div>
  </div><hr class="my-2">
  <table class="table table-sm" id="sItems"><thead><tr><th>Mahsulot</th><th class="text-end">Miqdor</th><th class="text-end">Narx</th><th>COGS usuli</th><th class="text-end">Jami</th><th></th></tr></thead><tbody>
  <tr class="template" style="display:none"><td><select name="product_id[]" class="form-select form-select-sm"><option value="">—</option><?php foreach($prod as $p): ?><option value="<?=$p['id']?>"><?=$p['code']?> — <?=$p['name']?></option><?php endforeach; ?></select></td>
  <td><input name="qty[]" type="number" class="form-control form-control-sm text-end" step="0.001" value="1"></td>
  <td><input name="price[]" type="number" class="form-control form-control-sm text-end" step="0.01" value="0"></td>
  <td><select name="method[]" class="form-select form-select-sm"><option value="FIFO">FIFO</option><option value="FEFO">FEFO</option></select></td>
  <td class="text-end line-total">0.00</td><td><button type="button" class="btn btn-outline-secondary btn-sm" onclick="this.closest('tr').remove()"><i class="bi bi-trash"></i></button></td></tr>
  </tbody></table>
  <button type="button" class="btn btn-outline-primary btn-sm" onclick="ItemsTable.addRow('#sItems')"><i class="bi bi-plus"></i> Qator qo‘shish</button>
</div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>
